#
# spec file for package xz (Version 4.999.9beta)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           xz
Summary:        A Program for Compressing Files
Version:        4.999.9beta
Release:        3.2
Group:          Productivity/Archiving/Compression
License:        LGPLv2.1+
Url:            http://tukaani.org/lzma/
Source:         %{name}-4.999.9beta.tar.bz2
Source2:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{?suse_version:%{suse_version}}%{!?suse_version:1110} >= 1100
BuildRequires:  pkg-config
%endif
Provides:       lzma = %version
Obsoletes:      lzma < %version
# avoid bootstrapping problem
%define _binary_payload w9.bzdio

%description
The xz command is a very powerful program for compressing files.

* Average compression ratio of LZMA is about 30% better than that of
   gzip, and 15% better than that of bzip2.

* Decompression speed is only little slower than that of gzip, being
   two to five times faster than bzip2.

* In fast mode, compresses faster than bzip2 with a comparable
   compression ratio.

* Achieving the best compression ratios takes four to even twelve
   times longer than with bzip2. However. this doesn't affect
   decompressing speed.

* Very similar command line interface to what gzip and bzip2 have.

%package -n liblzma0
License:        LGPLv2.1+
Summary:        LZMA library
Group:          System/Libraries

%description -n liblzma0
Library for encoding/decoding LZMA files.

%package devel
License:        LGPLv2.1+
Summary:        Development package for the LZMA library
Group:          Development/Libraries/C and C++
Requires:       liblzma0 = %{version}
Provides:       lzma-devel = %version
Obsoletes:      lzma-devel < %version
Provides:       lzma-alpha-devel = %version
Obsoletes:      lzma-alpha-devel < %version

%description devel
This package contains the header files and libraries needed for
compiling programs using the LZMA library.

%prep
%setup -q -n %{name}-4.999.9beta

%build
%if %{?suse_version:%{suse_version}}%{!?suse_version:1110} >= 1100
AUTOPOINT=true autoreconf -fi
%endif
%configure --libdir=/%{_lib} --disable-static --with-pic --docdir=%_docdir/%name
make %{?jobs:-j%jobs}

%check
LD_LIBRARY_PATH=$PWD/src/liblzma/.libs make check

%install
make install DESTDIR=$RPM_BUILD_ROOT
%{__mkdir_p} %{buildroot}%{_libdir}
%{__ln_s} -v /%{_lib}/$(readlink %{buildroot}/%{_lib}/liblzma.so) %{buildroot}%{_libdir}/liblzma.so
%{__mv} -v  %{buildroot}/%{_lib}/pkgconfig %{buildroot}%{_libdir}
%{__rm} -v %{buildroot}/%{_lib}/liblzma.{so,la}

%clean
rm -fr $RPM_BUILD_ROOT

%post -n liblzma0 -p /sbin/ldconfig

%postun -n liblzma0 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%_docdir/%name
%{_bindir}/*
%{_mandir}/man?/*

%files -n liblzma0
%defattr(-, root, root)
/%{_lib}/lib*.so.0*

%files devel
%defattr(-, root, root)
%{_includedir}/*.h
%{_includedir}/lzma
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Sat Dec 12 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Sep  4 2009 coolo@novell.com
- update to 4.999.9beta
  * only some polishment above the git snapshot I took
* Sun Aug 23 2009 coolo@novell.com
- borrow %%check section from fedora spec
* Thu Aug 20 2009 coolo@novell.com
- update to latest git (5.0 still not released)
  * a xz man page (bnc#505969)
  * fix data corruption in LZ/LZMA2 encoder.
  * major documentation update
  * install lzdiff, lzgrep, and lzmore as symlinks
  * make the default memory usage limit 40 %% of RAM for both
  compressing and decompressing.
  * fixed a crash in liblzma
  See git://ctrl.tukaani.org/xz.git for more
* Sun Jun  7 2009 crrodriguez@suse.de
- remove static libraries, see bnc#509945 for details
* Sun Feb 22 2009 ro@suse.de
- added baselibs.conf (for rpm-32bit)
* Mon Feb 16 2009 coolo@suse.de
- use bzip payload, so users are able to install new rpm on old systems
* Wed Feb 11 2009 coolo@suse.de
- fix devel symlink
* Fri Feb  6 2009 schwab@suse.de
- Update to xz-4.999.8beta.
  See git://ctrl.tukaani.org/lzma-utils.git.
* Wed Jan  7 2009 schwab@suse.de
- Update to xz-4.999.7beta.
  See git://ctrl.tukaani.org/lzma-utils.git.
- Rename to xz.
* Wed Jul 30 2008 schwab@suse.de
- Update to lzma-4.32.7.
  * If "lzma -t" is run on a corrupt file or interrupted by a signal,
    don't unlink /dev/null.
  * Partial fix to race conditions where a signal could make lzma to
    unlink both the source and destination files. Now it cannot lose
    data anymore, but with bad luck an incomplete file may be left
    on the disk.
* Wed May 14 2008 schwab@suse.de
- Update to lzma-4.32.6.
  * Always use 32-bit integer to hold probability variables. Earlier,
    these were 64-bit on 64-bit architectures, which hurt cache
    efficiency in the CPU, and thus performance of LZMA. 32-bit
    architectures are not affected by this change.
  * Fix a theoretical data corruption bug in the LZMA encoder. It is
    about overflowing a 32-bit integer, whose typical value stays below
    five. I don't know if it is actually possible to construct to a file
    that could make it overflow. Even if it were possible, it would "only"
    make the output file corrupt so that it is 4 GiB too small; there
    are no other security risks. Now the integer is 64-bit to be sure
    it won't overflow.
  * Add support for copying timestamps on operating systems that support
    setting timestamps only by filename, not by file descriptor.
  * Several portability fixes were made.
* Fri May  9 2008 schwab@suse.de
- Revert last changes.
* Tue May  6 2008 bk@suse.de
- ci removed #neededforbuild while mbuild converts to BuildRequires
- bzip2 source to save space (not lzma, so it can be built in <11.0)
* Tue May  6 2008 bk@suse.de
- run the package-provided self-test by adding a call to 'make check'
- use %%configure instead of equivalent configure call with options
- improved to allow building in SLES and non-SUSE repositories, eg:
  - replace obsolete nostatic patch with check for static objects
  - use more generic wildcards in the file list for manual pages
* Mon Feb  4 2008 schwab@suse.de
- Fix installation.
* Mon Feb  4 2008 schwab@suse.de
- Update to lzma-4.32.5.
  * The percentage shown when --verbose is used, works again. Also some
    typos were fixed from the messages printed by --verbose.
  * Several small portability fixes were made.
* Fri Jan  4 2008 crrodriguez@suse.de
- Version 4.32.4
  * Ignore command line switch --format=alone. This way current scripts
    can be written so that they will produce LZMA_Alone format files
    even with the new command line tool once it is finishes along with
    liblzma.
  * The command line tool now tells if the user tries to decode files
    in the new .lzma format. The message recommends upgrading to newer
    LZMA Utils.
  * Added some internal consistency checks to liblzmadec, so that it
    doesn't crash if given lzmadec_stream whose initialization failed.
    Some applications using zlib and libbzip2 don't check if
    initialization was successful, and expect that error gets caught
    safely later.
- disable static libraries
- remove liblzmadec.la that has empty dependency_libs
- do not link utils statically
* Mon Dec  3 2007 dmueller@suse.de
- update to 4.32.3:
  * rare file content loss bugs fixed (did not check for error upon close())
  * permissions copying fixed
- testsuited switched partially to GPLv3
- fix library package name
* Thu Oct 11 2007 schwab@suse.de
- Fix missing include.
* Wed Oct 10 2007 schwab@suse.de
- Initial version 4.32.0beta5.
